# コアコンセプト

## 設計モデル

- Python はルートとハンドラーを宣言します
- Rust はネットワーク/ランタイム作業を実行します
- `Context` はリクエストのメタデータを伝送します

## ハンドラールール

- `async def` である必要があります
- 最初の引数は `ctx` である必要があります
- 追加の型付き引数はルート/クエリからバインドされます

## ランタイムの所有権

`app.run()` は、ネイティブ ランタイムとワーカー モデルを開始します。